App.SettingsRoute = Ember.Route.extend({
    setupController: function(controller, model) {
        this.controllerFor('index').set('sidebarActiveButton', "settings-active");
        controller.set('model', model);
    },
    renderTemplate: function() {
        this.render('sidebar', { // the template to render
            outlet: 'sidebar', // the name of the outlet in the route's template
            controller: 'index' // the controller to use for the template
        });
        this.render('settings', {
            outlet: 'content',
        });
        this.render('blank', {
            outlet: 'details',
        });
    },
    model: function() {
        return App.Settings.create();
    },
});

App.SettingsController = Ember.ObjectController.extend({
    needs: 'application',

    actions: {

        showLogs: function() {
            settings.showLogs();
        },
        checkForUpdates: function() {
            updater.checkForUpdates();
        },
        sendToStore: function() {
            settings.sendToStore();
        },
        enterLicense: function() {
            this.set("showSerialEntry", true);
        },
        activate: function() {
            App.license.set("serial", this.get("serial"));
            App.license.activateSerial(function() {
                alert("Thanks for purchasing ExpanDrive!");
            });
        },

        installTerminalUtility: function() {
            settings.installTerminalUtility(this.get("terminalUtilityLocation"));
        }

    },
    licenseStatusMessage: function() {
        return "Jeff";
        //return expandrivelicense.licenseStatusMessage();
    }.property(),
    needsLicense: function() {
        return true;
        //return expandrivelicense.needsLicense();
    }.property(),

    showInDockMessage: function() {
        if(this.get("controllers.application").get("isPlatformWindows")) {
            return "Show in System Tray";
        } else {
            return "Show in Dock";
        }
    }.property(),

    serial: null,

    showSerialEntry: false,

    terminalUtilityLocations: [{
        name: "/usr/bin",
        value: "/usr/bin"
    }, {
        name: "/usr/local/bin",
        value: "/usr/local/bin"
    }, {
        name: "/opt/local/bin",
        value: "/opt/local/bin"
    }, {
        name: "/bin",
        value: "/bin"
    } ],

    terminalUtilityLocation: null

});

App.Settings = Ember.Model.extend({

    showInDock: function(key, value) {
        if (arguments.length > 1) {
            settings.showInDock(value)
            settings.setBool(value, "ShowInDock");
        }
        return settings.getBool("ShowInDock") == 1;
    }.property(),

    revealAfterConnect: function(key, value) {
        if (arguments.length > 1) {
            settings.setBool(value, "RevealAfterConnect");
        }
        return settings.getBool("RevealAfterConnect") == 1;
    }.property(),

    showManagerAtLaunch: function(key, value) {
        if (arguments.length > 1) {
            settings.setBool(value, "ShowManagerAtLaunch");
        }
        return settings.getBool("ShowManagerAtLaunch") == 1;
    }.property(),

    showDesktopNotifications: function(key, value) {
        if (arguments.length > 1) {
            settings.setBool(value, "ShowDesktopNotifications");
        }
        return settings.getBool("ShowDesktopNotifications") == 1;
    }.property(),

    enableAutomaticChecks: function(key, value) {
        if (arguments.length > 1) {
            settings.setBool(value, "SUEnableAutomaticChecks");
        }
        return settings.getBool("SUEnableAutomaticChecks") == 1;
    }.property(),

    startAtLogin: function(key, value) {
        if (arguments.length > 1) {
            loginitem.setLaunchAtLogon(value)
        }
        return loginitem.willLaunchAtLogon() == 1;
    }.property(),


    bundleversion: function() {
        return settings.bundleversion();
    }.property(),



    license: App.license,
});
